# FieldReport

Field report commands are used to write a field output report and free body computational results to an ASCII file.

## Create field reports in Session

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FieldReportSession.FieldReportSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.FieldReport.FieldReportOptions.FieldReportOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.FieldReport.FreeBodyReportOptions.FreeBodyReportOptions
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.FieldReport.OdbFieldVarList.OdbFieldVarList
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.FieldReport.OdbModelFieldVarList.OdbModelFieldVarList
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. automodule:: abaqus.FieldReport.writeFieldReport
        :members:

    .. automodule:: abaqus.FieldReport.writeFreeBodyReport
        :members:
```
